#ifndef AST_STR_DEFS_H
#define AST_STR_DEFS_H

#define AST_STR_DEFS \
	X(kind, "kind") \
	X(flags, "flags") \
	X(lineno, "lineno") \
	X(children, "children") \
	X(name, "name") \
	X(docComment, "docComment") \
	X(endLineno, "endLineno") \
	X(__declId, "__declId") \
	X(flagsCombinable, "flagsCombinable") \
	X(clone, "clone") \
	X(exit, "exit") \
	X(type, "type") \
	X(params, "params") \
	X(uses, "uses") \
	X(stmts, "stmts") \
	X(returnType, "returnType") \
	X(attributes, "attributes") \
	X(extends, "extends") \
	X(implements, "implements") \
	X(expr, "expr") \
	X(var, "var") \
	X(offset, "offset") \
	X(label, "label") \
	X(depth, "depth") \
	X(class, "class") \
	X(const, "const") \
	X(dim, "dim") \
	X(prop, "prop") \
	X(args, "args") \
	X(left, "left") \
	X(right, "right") \
	X(value, "value") \
	X(key, "key") \
	X(default, "default") \
	X(cond, "cond") \
	X(declares, "declares") \
	X(hooks, "hooks") \
	X(props, "props") \
	X(traits, "traits") \
	X(adaptations, "adaptations") \
	X(method, "method") \
	X(insteadof, "insteadof") \
	X(alias, "alias") \
	X(prefix, "prefix") \
	X(true, "true") \
	X(false, "false") \
	X(try, "try") \
	X(catches, "catches") \
	X(finally, "finally") \
	X(init, "init") \
	X(loop, "loop") \
	X(bracketed_closure, "{closure}") \

#endif
